#undef PACKAGE
#undef VERSION
#undef HAVE_LIBSM
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef ENABLE_NLS
#undef ENABLE_BONOBO
#undef ENABLE_GPRINT
#undef USING_OAF
#undef HAVE_PNG
#undef HAVE_JPEG
#undef HAVE_PROGRESSIVE_JPEG
#undef ENABLE_BONOBO_FILESEL
#undef ENABLE_EVOLUTION
#undef ENABLE_GNOCAM
#undef GETTEXT_PACKAGE
#undef GCONFTOOL
#undef GCONF_CONFIG_SOURCE
#undef INSTALL_GCONF_CONFIG_SOURCE

